@@ -1,6 +1,6 @@
 #!/bin/sh
 
-#    Copyright (C) 2008-2009 Canonical Ltd.
+#    Copyright 2008-2009 Canonical Ltd.
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License version 3,
@@ -15,10 +15,11 @@
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 testdir="tests"
-tests="installation bad good bugs util"
+tests="installation bad bugs good util"
 CUR=`pwd`
 export TESTPATH="$CUR/$testdir/testarea"
 export TESTTMP="$CUR/$testdir/testarea/tmp"
+export TESTSTATE="$TESTPATH/lib/ufw"
 
 STOPONFAIL="no"
 STOPONSKIP="no"
@@ -173,12 +174,13 @@ echo "Errors:              $errors"
 if [ "$errors" != "0" ]; then
 	exit 1
 fi
-if [ "$skipped" != "0" ]; then
-	exit 2
-fi
 
 # cleanup
 rm -rf $statsdir
 
+if [ "$skipped" != "0" ]; then
+	exit 2
+fi
+
 exit 0
 
