@@ -1,7 +1,7 @@
 #
 # backend.py: interface for backends
 #
-# Copyright (C) 2008-2009 Canonical Ltd.
+# Copyright 2008-2009 Canonical Ltd.
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License version 3,
@@ -23,7 +23,7 @@ from stat import *
 import sys
 import ufw.util
 from ufw.util import warn, debug
-from ufw.common import UFWError, config_dir, UFWRule
+from ufw.common import UFWError, config_dir, iptables_dir, UFWRule
 import ufw.applications
 
 class UFWBackend:
@@ -55,7 +55,14 @@ class UFWBackend:
             raise
 
         self.profiles = ufw.applications.get_profiles(self.files['apps'])
-        self.iptables_version = ufw.util.get_iptables_version()
+
+        self.iptables = os.path.join(iptables_dir, "iptables")
+        self.iptables_restore = os.path.join(iptables_dir, "iptables-restore")
+        self.ip6tables = os.path.join(iptables_dir, "ip6tables")
+        self.ip6tables_restore = os.path.join(iptables_dir, \
+                                              "ip6tables-restore")
+
+        self.iptables_version = ufw.util.get_iptables_version(self.iptables)
 
     def _is_enabled(self):
         if self.defaults.has_key('enabled') and \
@@ -135,8 +142,10 @@ class UFWBackend:
                     raise
 
                 if statinfo.st_uid != 0 and not warned_owner.has_key(path):
-                    warn_msg = _("uid is %s but '%s' is owned by %s") % \
-                                (str(uid), path, str(statinfo.st_uid))
+                    warn_msg = _("uid is %(uid)s but '%(path)s' is owned by " \
+                                 "%(st_uid)s") % ({'uid': str(uid), \
+                                               'path': path, \
+                                               'st_uid': str(statinfo.st_uid)})
                     warn(warn_msg)
                     warned_owner[path] = True
                 if mode & S_IWOTH and not warned_world_write.has_key(path):
@@ -157,8 +166,8 @@ class UFWBackend:
 
         for f in self.files:
             if f != 'apps' and not os.path.isfile(self.files[f]):
-                err_msg = _("'%s' file '%s' does not exist") % (f, \
-                                                                self.files[f])
+                err_msg = _("'%(f)s' file '%(name)s' does not exist") % \
+                           ({'f': f, 'name': self.files[f]})
                 raise UFWError(err_msg)
 
     def _get_defaults(self):
@@ -178,6 +187,19 @@ class UFWBackend:
 
             orig.close()
 
+        # do some default policy sanity checking
+        policies = ['accept', 'accept_no_track', 'drop', 'reject']
+        for c in [ 'input', 'output', 'forward' ]:
+            if not self.defaults.has_key('default_%s_policy' % (c)):
+                err_msg = _("Missing policy for '%s'" % (c))
+                raise UFWError(err_msg)
+            p = self.defaults['default_%s_policy' % (c)]
+            if p not in policies or \
+               (p == 'accept_no_track' and c == 'forward'):
+                err_msg = _("Invalid policy '%(policy)s' for '%(chain)s'" % \
+                            ({'policy': p, 'chain': c}))
+                raise UFWError(err_msg)
+
     def set_default(self, f, opt, value):
         '''Sets option in defaults file'''
         if not re.match(r'^[\w_]+$', opt):
@@ -533,7 +555,7 @@ class UFWBackend:
     def get_default_policy(self):
         raise UFWError("UFWBackend.get_default_policy: need to override")
 
-    def set_default_policy(self, policy):
+    def set_default_policy(self, policy, direction):
         raise UFWError("UFWBackend.set_default_policy: need to override")
 
     def get_running_raw(self):
@@ -561,3 +583,4 @@ class UFWBackend:
     def update_logging(self, level):
         raise UFWError("UFWBackend.update_logging: need to override")
 
+
