@@ -1,7 +1,7 @@
 #
 # backend_iptables.py: iptables backend for ufw
 #
-# Copyright (C) 2008-2009 Canonical Ltd.
+# Copyright 2008-2009 Canonical Ltd.
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License version 3,
@@ -37,7 +37,7 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
         files['rules6'] = os.path.join(state_dir, 'user6.rules')
         files['before6_rules'] = os.path.join(config_dir, 'ufw/before6.rules')
         files['after6_rules'] = os.path.join(config_dir, 'ufw/after6.rules')
-        files['init'] = os.path.join(prefix_dir, 'share/ufw/ufw-init')
+        files['init'] = os.path.join(state_dir, 'ufw-init')
 
         ufw.backend.UFWBackend.__init__(self, "iptables", d, files)
 
@@ -64,6 +64,8 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
         rstr = ""
         if self.defaults[policy] == "accept":
             rstr = "allow"
+        elif self.defaults[policy] == "accept_no_track":
+            rstr = "allow-without-tracking"
         elif self.defaults[policy] == "reject":
             rstr = "reject"
         else:
@@ -85,30 +87,39 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
 
         return rstr
 
-    def set_default_policy(self, policy):
+    def set_default_policy(self, policy, direction):
         '''Sets default policy of firewall'''
         if not self.dryrun:
             if policy != "allow" and policy != "deny" and policy != "reject":
                 err_msg = _("Unsupported policy '%s'") % (policy)
                 raise UFWError(err_msg)
 
+            if direction != "incoming" and direction != "outgoing":
+                err_msg = _("Unsupported policy for direction '%s'") % \
+                            (direction)
+                raise UFWError(err_msg)
+
+            chain = "INPUT"
+            if direction == "outgoing":
+                chain = "OUTPUT"
+
             old_log_str = ''
             new_log_str = ''
             if policy == "allow":
                 self.set_default(self.files['defaults'], \
-                                            "DEFAULT_INPUT_POLICY", \
+                                            "DEFAULT_%s_POLICY" % (chain), \
                                             "\"ACCEPT\"")
                 old_log_str = 'UFW BLOCK'
                 new_log_str = 'UFW ALLOW'
             elif policy == "reject":
                 self.set_default(self.files['defaults'], \
-                                            "DEFAULT_INPUT_POLICY", \
+                                            "DEFAULT_%s_POLICY" % (chain), \
                                             "\"REJECT\"")
                 old_log_str = 'UFW ALLOW'
                 new_log_str = 'UFW BLOCK'
             else:
                 self.set_default(self.files['defaults'], \
-                                            "DEFAULT_INPUT_POLICY", \
+                                            "DEFAULT_%s_POLICY" % (chain), \
                                             "\"DROP\"")
                 old_log_str = 'UFW ALLOW'
                 new_log_str = 'UFW BLOCK'
@@ -130,7 +141,8 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
 
                 ufw.util.close_files(fns)
 
-        rstr = _("Default policy changed to '%s'\n") % (policy)
+        rstr = _("Default %(direction)s policy changed to '%(policy)s'\n") % \
+                 ({'direction': direction, 'policy': policy})
         rstr += _("(be sure to update your rules accordingly)")
 
         return rstr
@@ -146,14 +158,16 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
 
         out = "IPV4:\n"
         for table in ['filter', 'nat', 'mangle', 'raw']:
-            (rc, tmp) = cmd(['iptables', '-L', '-n', '-v', '-x', '-t', table])
+            (rc, tmp) = cmd([self.iptables, '-L', '-n', '-v', '-x', '-t', \
+                             table])
             out += tmp
             if rc != 0:
                 raise UFWError(out)
 
         out += "\n\nIPV6:\n"
         for table in ['filter', 'mangle', 'raw']:
-            (rc, tmp) = cmd(['ip6tables', '-L', '-n', '-v', '-x', '-t', table])
+            (rc, tmp) = cmd([self.ip6tables, '-L', '-n', '-v', '-x', '-t', \
+                             table])
             out += tmp
             if rc != 0:
                 raise UFWError(out)
@@ -170,25 +184,29 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
                 out += "> " + _("Checking ip6tables\n")
             return out
 
-        # Is the firewall loaded at all?
-        (rc, out) = cmd(['iptables', '-L', 'ufw-user-input', '-n'])
-        if rc != 0:
-            return _("Status: inactive")
-
         err_msg = _("problem running")
-        if self.use_ipv6():
-            (rc, out6) = cmd(['ip6tables', '-L', 'ufw6-user-input', '-n'])
-            if rc != 0:
-                raise UFWError(err_msg + " ip6tables")
+        for direction in ["input", "output"]:
+            # Is the firewall loaded at all?
+            (rc, out) = cmd([self.iptables, '-L', \
+                            'ufw-user-%s' % (direction), '-n'])
+            if rc == 1:
+                return _("Status: inactive")
+            elif rc != 0:
+                raise UFWError(err_msg + " iptables: %s\n" % (out))
 
-        if out == "" and out6 == "":
-            return _("Status: active")
+            if self.use_ipv6():
+                (rc, out6) = cmd([self.ip6tables, '-L', \
+                                 'ufw6-user-%s' % (direction), '-n'])
+                if rc != 0:
+                    raise UFWError(err_msg + " ip6tables")
 
         str = ""
+        str_out = ""
         rules = self.rules + self.rules6
         count = 1
         app_rules = {}
         for r in rules:
+            tmp_str = ""
             location = {}
             tuple = ""
             show_proto = True
@@ -266,34 +284,76 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
                         if show_proto and r.protocol != "any" and \
                            r.dport == r.sport:
                             location[loc] += "/" + r.protocol
+                if loc == 'dst' and r.interface_in != "":
+                    location[loc] += " on %s" % (r.interface_in)
+                if loc == 'src' and r.interface_out != "":
+                    location[loc] += " on %s" % (r.interface_out)
 
+            attribs = []
+            attrib_str = ""
+            if r.logtype or r.direction.lower() == "out":
+                if r.logtype:
+                    attribs.append(r.logtype.lower())
+                if show_count and r.direction == "out":
+                    attribs.append(r.direction)
+                if len(attribs) > 0:
+                    attrib_str = " (%s)" % (', '.join(attribs))
+
+            # now contruct the rule output string
             if show_count:
-                str += "[%2d] " % (count)
-            
-            log_str = ""
-            if r.logtype:
-                log_str = " (%s)" % (r.logtype.lower())
-            str += "%-26s %-8s%s%s\n" % (location['dst'], r.action.upper(), \
-                    location['src'], log_str)
+                tmp_str += "[%2d] " % (count)
+
+            dir_str = r.direction.upper()
+            if r.direction == "in" and not verbose and not show_count:
+                dir_str = ""
+            tmp_str += "%-26s %-12s%s%s\n" % (location['dst'], \
+                                             " ".join([r.action.upper(), \
+                                                       dir_str]), \
+                                             location['src'], attrib_str)
+
+            # Show the list in the order given if a numbered list, otherwise
+            # split incoming and outgoing rules
+            if show_count:
+                str += tmp_str
+            else:
+                if r.direction == "out":
+                    str_out += tmp_str
+                else:
+                    str += tmp_str
             count += 1
 
-        if str != "":
-            header = "\n\n"
+        if str != "" or str_out != "":
+            full_str = "\n\n"
             if show_count:
-                header += "     "
-            header += "%-26s %-8s%s\n" % (_("To"), _("Action"), _("From"))
+                full_str += "     "
+            str_to = _("To")
+            str_from = _("From")
+            str_action = _("Action")
+            rules_header = "%-26s %-12s%s\n" % (str_to, str_action, str_from)
             if show_count:
-                header += "     "
-            header += "%-26s %-8s%s\n" % (_("--"), _("------"), _("----"))
-            str = header + str
+                rules_header += "     "
+            rules_header += "%-26s %-12s%s\n" % ("-" * len(str_to), \
+                                                 "-" * len(str_action), \
+                                                 "-" * len(str_from))
+            full_str += rules_header
+            if str != "":
+                full_str += str
+            if str != "" and str_out != "":
+                full_str += _("\n")
+            if str_out != "":
+                full_str += str_out
+
+            str = full_str
 
         if verbose:
             (level, logging_str) = self.get_loglevel()
-            policy_str = _("Default: %s") % (self.get_default_policy())
+            policy_str = _("Default: %(in)s (incoming), %(out)s (outgoing)") \
+                           % ({'in': self.get_default_policy(), \
+                               'out': self.get_default_policy("output")})
             app_policy_str = self.get_default_application_policy()
-            return _("Status: active\n%s\n%s\n%s%s") % \
-                                                    (logging_str, policy_str, \
-                                                     app_policy_str, str)
+            return _("Status: active\n%(log)s\n%(pol)s\n%(app)s%(status)s") % \
+                     ({'log': logging_str, 'pol': policy_str, \
+                       'app': app_policy_str, 'status': str})
         else:
             return _("Status: active%s") % (str)
 
@@ -338,10 +398,10 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
             return False
 
         prefix = "ufw"
-        exe = "iptables"
+        exe = self.iptables
         if v6:
             prefix = "ufw6"
-            exe = "ip6tables"
+            exe = self.ip6tables
 
         for chain in [ 'input', 'output', 'forward', 'limit', 'limit-accept' ]:
             if v6 and (chain == "limit" or chain == "limit-accept"):
@@ -372,17 +432,17 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
 
             # then restore the system rules
             (rc, out) = cmd_pipe(['cat', self.files['rules']], \
-                                 ['iptables-restore', '-n'])
+                                 [self.iptables_restore, '-n'])
             if rc != 0:
                 raise UFWError(err_msg + " iptables")
 
             if self.use_ipv6():
                 (rc, out) = cmd_pipe(['cat', self.files['rules6']], \
-                                     ['ip6tables-restore', '-n'])
+                                     [self.ip6tables_restore, '-n'])
                 if rc != 0:
                     raise UFWError(err_msg + " ip6tables")
 
-    def _get_rules_from_formatted(self, frule, prefix):
+    def _get_rules_from_formatted(self, frule, prefix, suffix):
         '''Return list of iptables rules appropriate for sending'''
         snippets = []
 
@@ -394,7 +454,7 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
             if pat_port.search(frule):
                 if pat_reject.search(frule):
                     snippets.append(pat_proto.sub('-p tcp ', \
-                        pat_reject.sub(r'-j \1 --reject-with tcp-reset ', \
+                        pat_reject.sub(r'-j \1 --reject-with tcp-reset', \
                         frule)))
                 else:
                     snippets.append(pat_proto.sub('-p tcp ', frule))
@@ -425,13 +485,13 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
                     lstr = '-m state --state NEW ' + lstr
                 snippets[i] = pat_log.sub(r'\1-j \2\4', s)
                 snippets.insert(i, pat_log.sub(r'\1-j ' + prefix + \
-                                               '-user-logging-input', s))
+                                               '-user-logging-' + suffix, s))
                 snippets.insert(i, pat_chain.sub(r'\1 ' + prefix + \
-                                                 '-user-logging-input', 
+                                                 '-user-logging-' + suffix,
                                                  pat_log.sub(r'\1-j RETURN', \
                                                  s)))
                 snippets.insert(i, pat_chain.sub(r'\1 ' + prefix + \
-                                                 '-user-logging-input', 
+                                                 '-user-logging-' + suffix,
                                                  pat_log.sub(r'\1' + lstr, s)))
 
         # adjust for limit
@@ -450,12 +510,12 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
 
         return snippets
 
-    def _get_lists_from_formatted(self, frule, prefix):
+    def _get_lists_from_formatted(self, frule, prefix, suffix):
         '''Return list of iptables rules appropriate for sending as arguments
            to cmd()
         '''
         snippets = []
-        str_snippets = self._get_rules_from_formatted(frule, prefix)
+        str_snippets = self._get_rules_from_formatted(frule, prefix, suffix)
 
         # split the string such that the log prefix can contain spaces
         pat = re.compile(r'(.*) --log-prefix (".* ")(.*)')
@@ -486,24 +546,36 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
                 if pat_tuple.match(line):
                     tuple = pat_tuple.sub('', line)
                     tmp = re.split(r'\s+', tuple.strip())
-                    if len(tmp) != 6 and len(tmp) != 8:
+                    if len(tmp) < 6 or len(tmp) > 9:
                         warn_msg = _("Skipping malformed tuple (bad length): %s") % (tuple)
                         warn(warn_msg)
                         continue
                     else:
+                        # set direction to "in" to support upgrades
+                        # from old format, which only had 6 or 8 fields
+                        type = "in"
+                        interface = ""
+                        if len(tmp) == 7 or len(tmp) == 9:
+                            if '_' in tmp[-1]:
+                                (type, interface) = tmp[-1].split('_')
+                            else:
+                                type = tmp[-1]
                         try:
-                            if len(tmp) == 6:
+                            if len(tmp) < 8:
                                 rule = UFWRule(tmp[0], tmp[1], tmp[2], tmp[3],
-                                               tmp[4], tmp[5])
+                                               tmp[4], tmp[5], type)
                             else:
                                 rule = UFWRule(tmp[0], tmp[1], tmp[2], tmp[3],
-                                               tmp[4], tmp[5])
+                                               tmp[4], tmp[5], type)
                                 # Removed leading [sd]app_ and unescape spaces
                                 pat_space = re.compile('%20')
                                 if tmp[6] != "-":
                                     rule.dapp = pat_space.sub(' ', tmp[6])
                                 if tmp[7] != "-":
                                     rule.sapp = pat_space.sub(' ', tmp[7])
+                            if interface != "":
+                                rule.set_interface(type, interface)
+
                         except UFWError:
                             warn_msg = _("Skipping malformed tuple: %s") % \
                                         (tuple)
@@ -560,8 +632,14 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
                 action += "_" + r.logtype
 
             if r.dapp == "" and r.sapp == "":
-                os.write(fd, "\n### tuple ### %s %s %s %s %s %s\n" % \
-                     (action, r.protocol, r.dport, r.dst, r.sport, r.src))
+                tstr = "\n### tuple ### %s %s %s %s %s %s %s" % \
+                     (action, r.protocol, r.dport, r.dst, r.sport, r.src, \
+                      r.direction)
+                if r.interface_in != "":
+                    tstr += "_%s" % (r.interface_in)
+                if r.interface_out != "":
+                    tstr += "_%s" % (r.interface_out)
+                os.write(fd, tstr + "\n")
             else:
                 pat_space = re.compile(' ')
                 dapp = "-"
@@ -570,13 +648,24 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
                 sapp = "-"
                 if r.sapp:
                     sapp = pat_space.sub('%20', r.sapp)
-                os.write(fd, "\n### tuple ### %s %s %s %s %s %s %s %s\n" \
-                     % (action, r.protocol, r.dport, r.dst, r.sport, r.src, \
-                        dapp, sapp))
+                tstr = "\n### tuple ### %s %s %s %s %s %s %s %s %s" % \
+                       (action, r.protocol, r.dport, r.dst, r.sport, r.src, \
+                        dapp, sapp, r.direction)
 
-            rule_str = "-A " + chain_prefix + "-user-input " + \
-                       r.format_rule() + "\n"
-            for s in self._get_rules_from_formatted(rule_str, chain_prefix):
+                if r.interface_in != "":
+                    tstr += "_%s" % (r.interface_in)
+                if r.interface_out != "":
+                    tstr += "_%s" % (r.interface_out)
+                os.write(fd, tstr + "\n")
+
+            chain_suffix = "input"
+            if r.direction == "out":
+                chain_suffix = "output"
+            chain = "%s-user-%s" % (chain_prefix, chain_suffix)
+            rule_str = "-A %s %s\n" % (chain, r.format_rule())
+
+            for s in self._get_rules_from_formatted(rule_str, chain_prefix, \
+                                                    chain_suffix):
                 os.write(fd, s)
 
         # Write footer
@@ -670,7 +759,7 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
                    (current[2] == '' and current[3] == '') or \
                    last != current:
                     inserted = True
-                    newrules.append(rule)
+                    newrules.append(rule.dup_rule())
                     last = ('', '', '', '')
                 else:
                     position += 1
@@ -686,13 +775,13 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
                 # skip it.
                 found = True
                 if not rule.remove:
-                    newrules.append(rule)
+                    newrules.append(rule.dup_rule())
             elif ret < 0 and not rule.remove and not inserted:
                 # If only the action is different, replace the rule if it's not
                 # to be removed.
                 found = True
                 modified = True
-                newrules.append(rule)
+                newrules.append(rule.dup_rule())
             else:
                 newrules.append(r)
 
@@ -705,7 +794,7 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
         else:
             # Add rule to the end if it was not already added.
             if not found and not rule.remove:
-                newrules.append(rule)
+                newrules.append(rule.dup_rule())
 
             # Don't process non-existing or unchanged pre-exisiting rules
             if not found and rule.remove and not self.dryrun:
@@ -741,11 +830,11 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
         if self._is_enabled() and not self.dryrun:
             flag = ""
             if modified or self._need_reload(rule.v6) or inserted:
-                rstr = _("Rule ")
+                rstr = ""
                 if inserted:
-                    rstr += _("inserted")
+                    rstr += _("Rule inserted")
                 else:
-                    rstr += _("updated")
+                    rstr += _("Rule updated")
                 if rule.v6:
                     rstr += " (v6)"
                 if allow_reload:
@@ -764,13 +853,17 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
                 rstr = _("Rule added")
 
             if flag != "":
-                exe = "iptables"
+                exe = self.iptables
                 chain_prefix = "ufw"
                 if rule.v6:
-                    exe = "ip6tables"
+                    exe = self.ip6tables
                     chain_prefix = "ufw6"
                     rstr += " (v6)"
-                chain = chain_prefix + "-user-input"
+                chain_suffix = "input"
+                if rule.direction == "out":
+                    chain_suffix = "output"
+                chain = "%s-user-%s" % (chain_prefix, chain_suffix)
+          
 
                 # Is the firewall running?
                 err_msg = _("Could not update running firewall")
@@ -781,7 +874,8 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
                 rule_str = "%s %s %s" % (flag, chain, rule.format_rule())
                 pat_log = re.compile(r'(-A +)(ufw6?-user-[a-z\-]+)(.*)')
                 for s in self._get_lists_from_formatted(rule_str, \
-                                                               chain_prefix):
+                                                        chain_prefix, \
+                                                        chain_suffix):
                     (rc, out) = cmd([exe] + s)
                     if rc != 0:
                         msg(out, sys.stderr)
@@ -822,15 +916,15 @@ class UFWBackendIptables(ufw.backend.UFWBackend):
 
     def _chain_cmd(self, chain, args, fail_ok=False):
         '''Perform command on chain'''
-        exe = "iptables"
+        exe = self.iptables
         if chain.startswith("ufw6"):
-            exe = "ip6tables"
+            exe = self.ip6tables
         (rc, out) = cmd([exe] + args)
         if rc != 0:
            err_msg = _("Could not perform '%s'") % (args)
            if fail_ok:
                debug("FAILOK: " + err_msg)
-           else: 
+           else:
                raise UFWError(err_msg)
 
     def update_logging(self, level):
