@@ -1,7 +1,7 @@
 #
 # frontend.py: frontend interface for ufw
 #
-# Copyright (C) 2008-2009 Canonical Ltd.
+# Copyright 2008-2009 Canonical Ltd.
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License version 3,
@@ -119,6 +119,17 @@ def parse_command(argv):
             action = "show-raw"
 
     if action == "default":
+        direction = "incoming"
+        if nargs > 3:
+            if argv[3].lower() != "incoming" and argv[3].lower() != "input" and \
+               argv[3].lower() != "output" and argv[3].lower() != "outgoing":
+                raise ValueError()
+            if argv[3].lower().startswith("in"):
+                direction = "incoming"
+            elif argv[3].lower().startswith("out"):
+                direction = "outgoing"
+            else:
+                direction = argv[3].lower()
         if nargs < 3:
             raise ValueError()
         elif argv[2].lower() == "deny":
@@ -130,25 +141,67 @@ def parse_command(argv):
         else:
             raise ValueError()
 
+        action += "-%s" % (direction)
+
     if action == "allow" or action == "deny" or action == "reject" or \
        action == "limit":
-        if nargs > 2 and (argv[2].lower() == "log" or \
-                          argv[2].lower() == 'log-all'):
-            if nargs < 4:
-                raise ValueError()
-            logtype = argv[2].lower()
+        # set/strip
+        rule_direction = "in"
+        if nargs > 2 and (argv[2].lower() == "in" or \
+                          argv[2].lower() == "out"):
+            rule_direction = argv[2].lower()
 
-            # strip out 'log' or 'log-all' and parse as normal
+        # strip out direction if not an interface rule
+        if nargs > 3 and argv[3] != "on" and (argv[2].lower() == "in" or \
+                                              argv[2].lower() == "out"):
+            rule_direction = argv[2].lower()
             del argv[2]
             nargs = len(argv)
 
-        if nargs < 3 or nargs > 12:
+        # strip out 'on' as in 'allow in on eth0 ...'
+        has_interface = False
+        if nargs > 2 and (argv.count('in') > 0 or argv.count('out') > 0):
+            err_msg = _("Invalid interface clause")
+
+            if argv[2].lower() != "in" and argv[2].lower() != "out":
+                raise UFWError(err_msg)
+            if nargs < 4 or argv[3].lower() != "on":
+                raise UFWError(err_msg)
+
+            del argv[3]
+            nargs = len(argv)
+            has_interface = True
+
+        log_idx = 0
+        if has_interface and nargs > 4 and (argv[4].lower() == "log" or \
+                                            argv[4].lower() == 'log-all'):
+            log_idx = 4
+        elif nargs > 3 and (argv[2].lower() == "log" or \
+                           argv[2].lower() == 'log-all'):
+            log_idx = 2
+
+        if log_idx > 0:
+            logtype = argv[log_idx].lower()
+            # strip out 'log' or 'log-all' and parse as normal
+            del argv[log_idx]
+            nargs = len(argv)
+
+        if "log" in argv:
+            err_msg = _("Option 'log' not allowed here")
+            raise UFWError(err_msg)
+
+        if "log-all" in argv:
+            err_msg = _("Option 'log-all' not allowed here")
+            raise UFWError(err_msg)
+
+        if nargs < 3 or nargs > 14:
             raise ValueError()
 
         rule_action = action
         if logtype != "":
             rule_action += "_" + logtype
-        rule = ufw.common.UFWRule(rule_action, "any", "any")
+        rule = ufw.common.UFWRule(rule_action, "any", "any", \
+                                  direction=rule_direction)
         if remove:
             rule.remove = remove
         elif insert_pos != "":
@@ -190,18 +243,21 @@ def parse_command(argv):
         elif nargs % 2 != 0:
             err_msg = _("Wrong number of arguments")
             raise UFWError(err_msg)
-        elif not 'from' in argv and not 'to' in argv:
+        elif not 'from' in argv and not 'to' in argv and not 'in' in argv and \
+             not 'out' in argv:
             err_msg = _("Need 'to' or 'from' clause")
             raise UFWError(err_msg)
         else:
             # Full form with PF-style syntax
-            keys = [ 'proto', 'from', 'to', 'port', 'app' ]
+            keys = [ 'proto', 'from', 'to', 'port', 'app', 'in', 'out' ]
 
             # quick check
             if argv.count("to") > 1 or \
                argv.count("from") > 1 or \
                argv.count("proto") > 1 or \
                argv.count("port") > 2 or \
+               argv.count("in") > 1 or \
+               argv.count("out") > 1 or \
                argv.count("app") > 2 or \
                argv.count("app") > 0 and argv.count("proto") > 0:
                 err_msg = _("Improper rule syntax")
@@ -222,6 +278,18 @@ def parse_command(argv):
                     else:
                         err_msg = _("Invalid 'proto' clause")
                         raise UFWError(err_msg)
+                elif arg == "in" or arg == "out":
+                    if i+1 < nargs:
+                        try:
+                            if arg == "in":
+                                rule.set_interface("in", argv[i+1])
+                            elif arg == "out":
+                                rule.set_interface("out", argv[i+1])
+                        except Exception:
+                            raise
+                    else:
+                        err_msg = _("Invalid '%s' clause") % (arg)
+                        raise UFWError(err_msg)
                 elif arg == "from":
                     if i+1 < nargs:
                         try:
@@ -419,28 +487,60 @@ def parse_application_command(argv):
 def get_command_help():
     '''Print help message'''
     msg = _('''
-Usage: ''') + ufw.common.programName + _(''' COMMAND
+Usage: %(progname)s %(command)s
 
-Commands:
- enable				enables the firewall
- disable			disables the firewall
- default ARG			set default policy to ALLOW, DENY or REJECT
- logging ARG			set logging to OFF, ON or LEVEL
- allow|deny|reject ARG		add allow, deny or reject RULE
- delete RULE		 	delete the RULE
- insert NUM RULE	 	insert RULE at NUM
- status 			show firewall status
- status numbered		show firewall status as numbered list of RULES
- show ARG			show firewall report
- version			display version information
+%(commands)s:
+ %(enable)-31s enables the firewall
+ %(disable)-31s disables the firewall
+ %(default)-31s set default policy
+ %(logging)-31s set logging to %(level)s
+ %(allow)-31s add allow %(rule)s
+ %(deny)-31s add deny %(rule)s
+ %(reject)-31s add reject %(rule)s
+ %(limit)-31s add limit %(rule)s
+ %(delete)-31s delete %(urule)s
+ %(insert)-31s insert %(urule)s at %(number)s
+ %(status)-31s show firewall status
+ %(statusnum)-31s show firewall status as numbered list of %(rules)s
+ %(statusverbose)-31s show verbose firewall status
+ %(show)-31s show firewall report
+ %(version)-31s display version information
+
+%(appcommands)s:
+ %(applist)-31s list application profiles
+ %(appinfo)-31s show information on %(profile)s
+ %(appupdate)-31s update %(profile)s
+ %(appdefault)-31s set default application policy
+''' % ({'progname': ufw.common.programName, \
+         'command': "COMMAND", \
+         'commands': "Commands", \
+         'enable': "enable", \
+         'disable': "disable", \
+         'default': "default ARG", \
+         'logging': "logging LEVEL", \
+         'level': "LEVEL", \
+         'allow': "allow ARGS", \
+         'rule': "rule", \
+         'deny': "deny ARGS", \
+         'reject': "reject ARGS", \
+         'limit': "limit ARGS", \
+         'delete': "delete RULE", \
+         'urule': "RULE", \
+         'insert': "insert NUM RULE", \
+         'number': "NUM", \
+         'status': "status", \
+         'statusnum': "status numbered", \
+         'rules': "RULES", \
+         'statusverbose': "status verbose", \
+         'show': "show ARG", \
+         'version': "version", \
+         'appcommands': "Application profile commands", \
+         'applist': "app list", \
+         'appinfo': "app info PROFILE", \
+         'profile': "PROFILE", \
+         'appupdate': "app update PROFILE", \
+         'appdefault': "app default ARG"}))
 
-Application profile commands:
- app list			list application profiles
- app info PROFILE		show information on PROFILE
- app update PROFILE		update PROFILE
- app default ARG		set profile policy to ALLOW, DENY, REJECT or
-				SKIP
-''')
     return (msg)
 
 
@@ -515,11 +615,11 @@ class UFWFrontend:
 
         return res
 
-    def set_default_policy(self, policy):
+    def set_default_policy(self, policy, direction):
         '''Sets default policy of firewall'''
         res = ""
         try:
-            res = self.backend.set_default_policy(policy)
+            res = self.backend.set_default_policy(policy, direction)
             if self.backend._is_enabled():
                 self.backend.stop_firewall()
                 self.backend.start_firewall()
@@ -647,8 +747,8 @@ class UFWFrontend:
                         if not r.remove and user_pos > num_v4:
 			    # The user specified a v6 rule, so try to find a
 			    # match in the v4 rules and use its position.
-                            p = self.backend.find_other_position(user_pos - \
-                                                                 num_v4, True)
+                            p = self.backend.find_other_position( \
+                                user_pos - num_v4 + count, True)
                             if p > 0:
                                 r.set_position(p)
                             else:
@@ -753,12 +853,12 @@ class UFWFrontend:
                 res = self.set_loglevel("on")
         elif action == "logging-off":
             res = self.set_loglevel("off")
-        elif action == "default-allow":
-            res = self.set_default_policy("allow")
-        elif action == "default-deny":
-            res = self.set_default_policy("deny")
-        elif action == "default-reject":
-            res = self.set_default_policy("reject")
+        elif action.startswith("default-"):
+            err_msg = _("Unsupported default policy")
+            tmp = action.split('-')
+            if len(tmp) != 3:
+                raise UFWError(err_msg)
+            res = self.set_default_policy(tmp[1], tmp[2])
         elif action == "status":
             res = self.get_status()
         elif action == "status-verbose":
@@ -781,19 +881,34 @@ class UFWFrontend:
         elif action == "allow" or action == "deny" or action == "reject" or \
              action == "limit":
             # allow case insensitive matches for application rules
-            try:
-                if rule.dapp != "":
+            if rule.dapp != "":
+                try:
                     tmp = self.backend.find_application_name(rule.dapp)
                     if tmp != rule.dapp:
                         rule.dapp = tmp
                         rule.set_port(tmp, "dst")
-                if rule.sapp != "":
+                except UFWError, e:
+                    # allow for the profile being deleted (LP: #407810)
+                    if not rule.remove:
+                        error(e.value)
+                    if not ufw.applications.valid_profile_name(rule.dapp):
+                        err_msg = _("Invalid profile name")
+                        raise UFWError(err_msg)
+
+            if rule.sapp != "":
+                try:
                     tmp = self.backend.find_application_name(rule.sapp)
                     if tmp != rule.sapp:
                         rule.sapp = tmp
-                        rule.set_port(tmp, "src")
-            except UFWError, e:
-                error(e.value)
+                        rule.set_port(tmp, "dst")
+                except UFWError, e:
+                    # allow for the profile being deleted (LP: #407810)
+                    if not rule.remove:
+                        error(e.value)
+                    if not ufw.applications.valid_profile_name(rule.sapp):
+                        err_msg = _("Invalid profile name")
+                        raise UFWError(err_msg)
+
             res = self.set_rule(rule, ip_version)
         else:
             err_msg = _("Unsupported action '%s'") % (action)
@@ -978,8 +1093,8 @@ class UFWFrontend:
         proceed = True
         if self.backend.do_checks and ufw.util.under_ssh():
             prompt = _("Command may disrupt existing ssh connections.")
-            prompt += _(" Proceed with operation (%s|%s)? ") % \
-                       (self.yes, self.no)
+            prompt += _(" Proceed with operation (%(yes)s|%(no)s)? ") % \
+                       ({'yes': self.yes, 'no': self.no})
             os.write(sys.stdout.fileno(), prompt)
             ans = sys.stdin.readline().lower().strip()
             if ans != "y" and ans != self.yes and ans != self.yes_full:
