@@ -1,7 +1,7 @@
 #
 # util.py: utility functions for ufw
 #
-# Copyright (C) 2008-2009 Canonical Ltd.
+# Copyright 2008-2009 Canonical Ltd.
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License version 3,
@@ -146,7 +146,7 @@ def valid_address(addr, version="any"):
 
 def normalize_address(orig, v6):
     '''Convert address to standard form. Use no netmask for IP addresses. If
-       If netmask is specified and not all 1's, for IPv4 use cidr if possible, 
+       If netmask is specified and not all 1's, for IPv4 use cidr if possible,
        otherwise dotted netmask and for IPv6, use cidr.
     '''
     net = []
@@ -514,9 +514,8 @@ def _address4_to_network(addr):
 
     return network + "/" + orig_nm
 
-def get_iptables_version():
+def get_iptables_version(exe="/sbin/iptables"):
     '''Return iptables version'''
-    exe = 'iptables'
     (rc, out) = cmd([exe, '-V'])
     if rc != 0:
         raise OSError(errno.ENOENT, "Error running '%s'" % (exe))
