@@ -1,6 +1,6 @@
 #!/bin/bash
 
-#    Copyright (C) 2008 Canonical Ltd.
+#    Copyright 2008-2009 Canonical Ltd.
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License version 3,
@@ -75,4 +75,15 @@ EOM
 do_cmd "1" null --dry-run allow runtest
 rm -f $TESTPATH/etc/ufw/applications.d/Runtest $TESTPATH/etc/ufw/applications.d/RunTest
 
+echo "TESTING ARGS (interfaces)" >> $TESTTMP/result
+for j in "in" "out"; do
+    for i in allow deny limit; do
+        do_cmd "1" null --dry-run $i $j on eth0:1 to any app Bind9
+        do_cmd "1" null --dry-run $i on eth0 to any app Bind9
+        do_cmd "1" null --dry-run $i $j ina on eth0 to any app Bind9
+        do_cmd "1" null --dry-run $i $j ona eth0 to any app Bind9
+        do_cmd "1" null --dry-run $i $j eth0 to any app Bind9
+    done
+done
+
 exit 0
