@@ -1,6 +1,6 @@
 #!/bin/bash
 
-#    Copyright (C) 2008 Canonical Ltd.
+#    Copyright 2008 Canonical Ltd.
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License version 3,
@@ -102,4 +102,11 @@ for i in 2001:0db8:85a3:08d3:1319:8a2e:0370:734 any; do
     done
 done
 
+echo "Interfaces" >> $TESTTMP/result
+for i in "in" "out" ; do
+    for j in allow deny reject ; do
+        do_cmd "0" null --dry-run $j $i on eth0 to 2001:0db8:85a3:08d3:1319:8a2e:0370:734
+        do_cmd "0" null --dry-run $j $i on eth0 from 2001:0db8:85a3:08d3:1319:8a2e:0370:734 port 22 proto tcp
+    done
+done
 exit 0
