@@ -1,6 +1,6 @@
 #!/bin/bash
 
-#    Copyright (C) 2008-2009 Canonical Ltd.
+#    Copyright 2008-2009 Canonical Ltd.
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License version 3,
@@ -17,34 +17,34 @@
 source "$TESTPATH/../testlib.sh"
 
 # setup
-do_cmd "0"  disable
-do_cmd "0"  enable
+do_cmd "0" nostats disable
+do_cmd "0" nostats enable
 
 echo "Bug #247352" >> $TESTTMP/result
 do_cmd "0" --dry-run allow http/tcp
-grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+grep -A2 "tuple" $TESTSTATE/user.rules >> $TESTTMP/result
 echo "iptables -L -n:" >> $TESTTMP/result
 iptables -L -n | grep -A2 "80" >> $TESTTMP/result 2>&1
 do_cmd "0" delete allow http/tcp
-grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+grep -A2 "tuple" $TESTSTATE/user.rules >> $TESTTMP/result
 
 echo "Bug #251355" >> $TESTTMP/result
 echo "Setting IPV6 to no" >> $TESTTMP/result
 sed -i "s/IPV6=.*/IPV6=no/" $TESTPATH/etc/default/ufw
-do_cmd "0"  disable
-echo "/usr/share/ufw/ufw-init flush-all:" >> $TESTTMP/result
-$TESTPATH/usr/share/ufw/ufw-init flush-all >> $TESTTMP/result 2>&1
-do_cmd "0"  enable
-echo "/usr/share/ufw/ufw-init force-reload:" >> $TESTTMP/result
-$TESTPATH/usr/share/ufw/ufw-init force-reload >> $TESTTMP/result 2>&1
+do_cmd "0" nostats disable
+echo "/lib/ufw/ufw-init flush-all:" >> $TESTTMP/result
+$TESTSTATE/ufw-init flush-all >> $TESTTMP/result 2>&1
+do_cmd "0" nostats enable
+echo "/lib/ufw/ufw-init force-reload:" >> $TESTTMP/result
+$TESTSTATE/ufw-init force-reload >> $TESTTMP/result 2>&1
 echo "ip6tables -L -n:" >> $TESTTMP/result
 ip6tables -L -n >> $TESTTMP/result 2>&1
 
 echo "Bug #260881" >> $TESTTMP/result
 echo "Setting IPV6 to no" >> $TESTTMP/result
 sed -i "s/IPV6=.*/IPV6=no/" $TESTPATH/etc/default/ufw
-do_cmd "0"  disable
-do_cmd "0"  enable
+do_cmd "0" nostats disable
+do_cmd "0" nostats enable
 do_cmd "0"  allow Apache
 do_cmd "0"  delete deny Apache
 echo "iptables -L -n:" >> $TESTTMP/result
@@ -56,8 +56,8 @@ iptables -L -n | grep -A2 "80" >> $TESTTMP/result 2>&1
 echo "Bug #263308" >> $TESTTMP/result
 echo "Setting IPV6 to yes" >> $TESTTMP/result
 sed -i "s/IPV6=.*/IPV6=yes/" $TESTPATH/etc/default/ufw
-do_cmd "0"  disable
-do_cmd "0"  enable
+do_cmd "0" nostats disable
+do_cmd "0" nostats enable
 do_cmd "0"  allow to any from any
 do_cmd "0"  allow proto tcp to any from any
 do_cmd "0"  allow to 192.168.1.1
@@ -76,8 +76,8 @@ do_cmd "0"  status
 echo "Bug #273278" >> $TESTTMP/result
 echo "Setting IPV6 to yes" >> $TESTTMP/result
 sed -i "s/IPV6=.*/IPV6=yes/" $TESTPATH/etc/default/ufw
-do_cmd "0"  disable
-do_cmd "0"  enable
+do_cmd "0" nostats disable
+do_cmd "0" nostats enable
 do_cmd "0"  status verbose
 cat $TESTPATH/etc/ufw/after*.rules | egrep 'LOG .*UFW ' >> $TESTTMP/result
 do_cmd "0"  default allow
@@ -90,8 +90,8 @@ cat $TESTPATH/etc/ufw/after*.rules | egrep 'LOG .*UFW ' >> $TESTTMP/result
 echo "Bug #251136" >> $TESTTMP/result
 echo "Setting IPV6 to yes" >> $TESTTMP/result
 sed -i "s/IPV6=.*/IPV6=yes/" $TESTPATH/etc/default/ufw
-do_cmd "0"  disable
-do_cmd "0"  enable
+do_cmd "0" nostats disable
+do_cmd "0" nostats enable
 do_cmd "0"  status
 do_cmd "0"  delete allow 22
 do_cmd "0"  delete allow Apache
@@ -104,8 +104,8 @@ do_cmd "0"  status
 echo "Bug #344971" >> $TESTTMP/result
 echo "Setting IPV6 to yes" >> $TESTTMP/result
 sed -i "s/IPV6=.*/IPV6=yes/" $TESTPATH/etc/default/ufw
-do_cmd "0"  disable
-do_cmd "0"  enable
+do_cmd "0" nostats disable
+do_cmd "0" nostats enable
 do_cmd "0"  allow 3
 do_cmd "0"  allow 4
 do_cmd "0"  insert 1 allow 1
@@ -117,6 +117,16 @@ do_cmd "0"  delete allow 2
 do_cmd "0"  delete allow 1
 do_cmd "0"  status
 
+echo "Bug #407810" >> $TESTTMP/result
+cp "$TESTPATH/etc/ufw/applications.d/samba" "$TESTPATH/etc/ufw/applications.d/bug407810"
+sed -i 's/Samba/bug407810/' "$TESTPATH/etc/ufw/applications.d/bug407810"
+do_cmd "0" app info bug407810
+do_cmd "0" null allow bug407810
+grep "^-A .*user-input" $TESTSTATE/user.rules >> $TESTTMP/result
+rm -f "$TESTPATH/etc/ufw/applications.d/bug407810"
+do_cmd "0" null delete allow bug407810
+grep "^-A .*user-input" $TESTSTATE/user.rules >> $TESTTMP/result
+
 # teardown
 cleanup
 
